<?php

global $severity_list;
$severity_list = array (

'1' =>  'Sehr niedrig',
'2' =>  'Niedrig',
'3' =>  'Mittel',
'4' =>  'Hoch',
'5' =>  'Kritisch',

);
?>
